@@ -94,7 +94,7 @@ IMainWindow::onInitDone()
 }//IMainWindow::onInitDone
 
 void
-IMainWindow::beginLogin(const QString &user, const QString &pass)
+IMainWindow::beginLogin(QString user, QString pass)
 {
     bool ok;
     do {
@@ -103,12 +103,16 @@ IMainWindow::beginLogin(const QString &user, const QString &pass)
             break;
         }
 
+        user = user.trimmed();
+        if (user.isEmpty ()) {
+            Q_WARN("Empty user name");
+            uiShowStatusMessage ("Cannot login: Username is empty", SHOW_10SEC);
+            break;
+        }
+
         // If the user doesnt put in the domain, put it in....
-        QString temp_user;
         if (!user.contains ('@')) {
-            temp_user = user.trimmed() + "@gmail.com";
-        } else {
-            temp_user = user;
+            user = user + "@gmail.com";
         }
 
         uiEnableContactUpdateFrequency (false);
@@ -128,10 +132,10 @@ IMainWindow::beginLogin(const QString &user, const QString &pass)
             Q_CRIT("Failed to connect signal");
         }
 
-        m_loginTask->inParams["user"] = temp_user;
+        m_loginTask->inParams["user"] = user;
         m_loginTask->inParams["pass"] = pass;
 
-        Q_DEBUG(QString("Login using user %1").arg(temp_user));
+        Q_DEBUG(QString("Login using user %1").arg(user));
         startLongTask (LT_Login);
 
         if (!gvApi.login (m_loginTask)) {
@@ -139,7 +143,7 @@ IMainWindow::beginLogin(const QString &user, const QString &pass)
             break;
         }
 
-        m_user = temp_user;
+        m_user = user;
         m_pass = pass;
         uiSetUserPass(false);
     } while (0);
