@@ -471,6 +471,51 @@ OsDependent::getAppDirectory ()
     return strStoreDir;
 }//OsDependent::getAppDirectory
 
+QString
+OsDependent::getLogDirectory ()
+{
+#ifdef Q_OS_BLACKBERRY
+    QString strDir = QDir::homePath ();
+    QDir dirHome(strDir);
+    if (!strDir.endsWith (QDir::separator ())) {
+        strDir += QDir::separator ();
+    }
+    strDir += "logs";
+    if (!QFileInfo(strDir).exists ()) {
+        dirHome.mkdir ("logs");
+    }
+    return strDir;
+#else
+    return getAppDirectory();
+#endif
+}//OsDependent::getLogDirectory
+
+QString
+OsDependent::getDbDirectory ()
+{
+#ifdef Q_OS_BLACKBERRY
+    return QDir::homePath();
+#else
+    return getAppDirectory();
+#endif
+}//OsDependent::getDbDirectory
+
+QString
+OsDependent::getTmpDirectory ()
+{
+#ifdef Q_OS_BLACKBERRY
+    return QDir::tempPath();
+#else
+    QString strTempStore = getAppDirectory ();
+    QDir dirApp(strTempStore);
+    strTempStore += QDir::separator() + tr("temp");
+    if (!QFileInfo(strTempStore).exists ()) {
+        dirApp.mkdir ("temp");
+    }
+    return (strTempStore);
+#endif
+}//OsDependent::getTmpDirectory
+
 QString
 OsDependent::getMainQML ()
 {
